"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs-extra");
const file_helpers_1 = require("./file-helpers");
const SRC_DIR_PATH = "srcDirPath";
const OUT_DIR_PATH = "outDirPath";
describe("File Helpers:", () => {
    let existsSyncSpy;
    beforeEach(() => {
        spyOn(fs, "writeFileSync");
        spyOn(fs, "readFileSync").and.returnValue("this is file content");
        existsSyncSpy = spyOn(fs, "existsSync").and.returnValue(true);
        spyOn(fs, "readJsonSync").and.returnValue({ hello: "world" });
    });
    describe("copyFileSync:", () => {
        let removeSyncSpy;
        beforeEach(() => {
            removeSyncSpy = spyOn(fs, "removeSync").and.returnValue(true);
            spyOn(fs, "copySync").and.returnValue(true);
        });
        it("should call fs.existsSync", () => {
            file_helpers_1.copyFileSync(SRC_DIR_PATH, OUT_DIR_PATH, false);
            expect(fs.existsSync).toHaveBeenCalledWith(SRC_DIR_PATH);
        });
        it("should return false when srcDirPath does not exist", () => {
            existsSyncSpy.and.returnValue(false);
            expect(file_helpers_1.copyFileSync(SRC_DIR_PATH, OUT_DIR_PATH, false)).toBeFalsy();
        });
        it("should return true when copy is succesuful", () => {
            expect(file_helpers_1.copyFileSync(SRC_DIR_PATH, OUT_DIR_PATH, false)).toBeTruthy();
        });
        it("should not delete outDir when cleanOutDir is false", () => {
            file_helpers_1.copyFileSync(SRC_DIR_PATH, OUT_DIR_PATH, false);
            expect(removeSyncSpy).not.toHaveBeenCalled();
        });
        it("should not delete outDir when no cleanOutDir is passed", () => {
            file_helpers_1.copyFileSync(SRC_DIR_PATH, OUT_DIR_PATH);
            expect(removeSyncSpy).not.toHaveBeenCalled();
        });
        it("should delete outDir when cleanOutDir is true", () => {
            file_helpers_1.copyFileSync(SRC_DIR_PATH, OUT_DIR_PATH, true);
            expect(removeSyncSpy).toHaveBeenCalledWith(OUT_DIR_PATH);
        });
    });
    xit("getFileListSync: should return file list objects when getFileListSync is called", () => {
        expect(file_helpers_1.getFileListSync(SRC_DIR_PATH)).toEqual([
            { path: "test_1", stats: {} },
            { path: "test_2", stats: {} },
        ]);
    });
    it("getFileContentSync: should return file content", () => {
        expect(file_helpers_1.getFileContentSync(SRC_DIR_PATH, "utf-8")).toEqual("this is file content");
    });
    it("getFileContentSync: should call fs.readFileSync with correct attributes", () => {
        file_helpers_1.getFileContentSync(SRC_DIR_PATH, "utf-8");
        expect(fs.readFileSync).toHaveBeenCalledWith(SRC_DIR_PATH, "utf-8");
    });
    it("writeToFileSync: should call fs.writeFileSync with correct attributes", () => {
        file_helpers_1.writeToFileSync(OUT_DIR_PATH, "file content");
        expect(fs.writeFileSync).toHaveBeenCalledWith(OUT_DIR_PATH, "file content", { flag: "w" });
    });
    it("fileExistSync should return false when file does not exist", () => {
        existsSyncSpy.and.returnValue(false);
        expect(file_helpers_1.fileExistSync(SRC_DIR_PATH)).toBeFalsy();
    });
    it("fileExistSync should return true when file exist", () => {
        expect(file_helpers_1.fileExistSync(SRC_DIR_PATH)).toBeTruthy();
    });
    it("getJsonSync should return json value", () => {
        expect(file_helpers_1.getJsonSync(SRC_DIR_PATH)).toEqual({ hello: "world" });
    });
});
