"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const FileHelpers = require("./file-helpers");
const insert_file_content_1 = require("./insert-file-content");
const model_1 = require("./model");
const TemplateContentSync = require("./template-content-sync");
const OPTIONS = {
    cleanOutDir: true,
    config: "./ifc.json",
    fileEncoding: "utf-16",
    lineRegExp: "string1",
    outDir: "outDirPath",
    srcDir: "srcDirPath",
    tokens: {},
};
const FILE_CONTENT = "file content";
const REPLACED_FILE_CONTENT = "replaced content";
const FILE_LIST = [{ path: "file1" }, { path: "file2" }, { path: "file3" }, { path: "file4" }];
describe("Insert File Content:", () => {
    let copyFileSyncSpy;
    let getFileContentSyncSpy;
    let replaceTokensAndLineRegExpSyncSpy;
    let writeToFileSyncSpy;
    beforeEach(() => {
        spyOn(FileHelpers, "getFileListSync").and.returnValue(FILE_LIST);
        copyFileSyncSpy = spyOn(FileHelpers, "copyFileSync").and.returnValue(true);
        getFileContentSyncSpy = spyOn(FileHelpers, "getFileContentSync").and.returnValue(FILE_CONTENT);
        writeToFileSyncSpy = spyOn(FileHelpers, "writeToFileSync").and.returnValue(true);
        replaceTokensAndLineRegExpSyncSpy = spyOn(TemplateContentSync, "replaceTokensAndLineRegExpSync")
            .and.returnValue(REPLACED_FILE_CONTENT);
    });
    describe("ifcSync:", () => {
        it("should copy files to OUT_DIR_PATH from SRC_DIR_PATH", () => {
            copyFileSyncSpy.and.returnValue(false);
            insert_file_content_1.ifcSync(OPTIONS);
            expect(FileHelpers.copyFileSync).toHaveBeenCalledWith(OPTIONS.srcDir, OPTIONS.outDir, OPTIONS.cleanOutDir);
            expect(FileHelpers.copyFileSync).toHaveBeenCalledTimes(1);
        });
        it("should get all files from outDir", () => {
            insert_file_content_1.ifcSync(OPTIONS);
            expect(FileHelpers.getFileListSync).toHaveBeenCalledWith(OPTIONS.outDir);
            expect(FileHelpers.getFileListSync).toHaveBeenCalledTimes(1);
        });
        it("should get file content for all files in outDir", () => {
            insert_file_content_1.ifcSync(OPTIONS);
            expect(getFileContentSyncSpy).toHaveBeenCalledTimes(4);
            expect(getFileContentSyncSpy.calls.argsFor(0)).toEqual([FILE_LIST[0].path, "utf-16"]);
            expect(getFileContentSyncSpy.calls.argsFor(1)).toEqual([FILE_LIST[1].path, "utf-16"]);
            expect(getFileContentSyncSpy.calls.argsFor(2)).toEqual([FILE_LIST[2].path, "utf-16"]);
            expect(getFileContentSyncSpy.calls.argsFor(3)).toEqual([FILE_LIST[3].path, "utf-16"]);
        });
        it("should call replaceTokensAndLineRegExpSync for each file", () => {
            insert_file_content_1.ifcSync(OPTIONS);
            expect(replaceTokensAndLineRegExpSyncSpy).toHaveBeenCalledTimes(4);
            expect(replaceTokensAndLineRegExpSyncSpy.calls.argsFor(0)).toEqual([FILE_CONTENT, OPTIONS]);
            expect(replaceTokensAndLineRegExpSyncSpy.calls.argsFor(1)).toEqual([FILE_CONTENT, OPTIONS]);
            expect(replaceTokensAndLineRegExpSyncSpy.calls.argsFor(2)).toEqual([FILE_CONTENT, OPTIONS]);
            expect(replaceTokensAndLineRegExpSyncSpy.calls.argsFor(3)).toEqual([FILE_CONTENT, OPTIONS]);
        });
        it("file content should be written to our dir for each file", () => {
            insert_file_content_1.ifcSync(OPTIONS);
            expect(writeToFileSyncSpy).toHaveBeenCalledTimes(4);
            expect(writeToFileSyncSpy.calls.argsFor(0)).toEqual([FILE_LIST[0].path, REPLACED_FILE_CONTENT]);
            expect(writeToFileSyncSpy.calls.argsFor(1)).toEqual([FILE_LIST[1].path, REPLACED_FILE_CONTENT]);
            expect(writeToFileSyncSpy.calls.argsFor(2)).toEqual([FILE_LIST[2].path, REPLACED_FILE_CONTENT]);
            expect(writeToFileSyncSpy.calls.argsFor(3)).toEqual([FILE_LIST[3].path, REPLACED_FILE_CONTENT]);
        });
        it("should set to default options", () => {
            spyOn(FileHelpers, "fileExistSync").and.returnValue(false);
            spyOn(Object, "assign").and.returnValue(OPTIONS);
            insert_file_content_1.ifcSync();
            expect(Object.assign).toHaveBeenCalledWith({}, model_1.defaultOptions, undefined, undefined);
        });
        it("should set to default options and user input options", () => {
            spyOn(FileHelpers, "fileExistSync").and.returnValue(false);
            spyOn(Object, "assign").and.returnValue(OPTIONS);
            insert_file_content_1.ifcSync(OPTIONS);
            expect(Object.assign).toHaveBeenCalledWith({}, model_1.defaultOptions, undefined, OPTIONS);
        });
        it("should set to default options, file options and user input options", () => {
            spyOn(FileHelpers, "fileExistSync").and.returnValue(true);
            spyOn(FileHelpers, "getJsonSync").and.returnValue({ outDir: "./outfile1" });
            spyOn(Object, "assign").and.returnValue(OPTIONS);
            insert_file_content_1.ifcSync({ srcDir: "srcDirPath1" });
            expect(Object.assign)
                .toHaveBeenCalledWith({}, model_1.defaultOptions, { outDir: "./outfile1" }, { srcDir: "srcDirPath1" });
        });
    });
});
