"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const file_helpers_1 = require("./file-helpers");
let cacheTemplates = {};
exports.replaceTokensAndLineRegExpSync = (content, options) => {
    content = replaceTokensWithContentSync(content, options);
    content = replaceLinesWithContentSync(content, options);
    return content;
};
exports.clearCache = () => {
    cacheTemplates = {};
};
const replaceTokensWithContentSync = (content, options) => {
    Object.keys(options.tokens).forEach((token) => {
        if (content.includes(token)) {
            const contentToReplace = getTemplateContentSync(options.tokens[token], options);
            if (contentToReplace && contentToReplace.length > 0) {
                content = content.replace(new RegExp(token, "g"), contentToReplace);
            }
        }
    });
    return content;
};
const replaceLinesWithContentSync = (content, options) => {
    if (options.lineRegExp && options.lineRegExp.trim().length > 0) {
        const lines = content.split("\n");
        lines.forEach((line) => {
            const match = line.match(new RegExp(options.lineRegExp));
            if (match !== null && match.length >= 1) {
                content = content.replace(new RegExp(line, "g"), getTemplateContentSync(match[1], options));
            }
        });
    }
    return content;
};
const getTemplateContentSync = (templatePath, options) => {
    if (!cacheTemplates[templatePath]) {
        cacheTemplateSync(templatePath, options);
    }
    return cacheTemplates[templatePath];
};
const cacheTemplateSync = (templatePath, options) => {
    let content = file_helpers_1.getFileContentSync(templatePath, options.fileEncoding);
    content = exports.replaceTokensAndLineRegExpSync(content, options);
    cacheTemplates[templatePath] = content;
};
